@@ -1,6 +1,7 @@
 from dataclasses import dataclass, field
 from enum import Enum
 from typing import Optional, Dict, List, Union, Any, Set
+import copy
 
 from box import Box, BoxList
 from dataclasses_json import dataclass_json, LetterCase, Undefined, CatchAll
@@ -106,33 +107,74 @@ class AWSArn:
 
 
 @dataclass
-class EventProperties:
-    event_type: str
+class BucketRow:
+    bucket_name: str
+    prefix: Optional[str] = None
+    suffix: Optional[str] = None
 
+
+@dataclass
+class ResourceProperties:
     bucket_name: str
     bucket_arn: str = field(init=False)
 
+    region: str
+    client: Any
+    account_id: str
+
+    prefix: Optional[str] = None
+    suffix: Optional[str] = None
+
+    topic_arn: Optional[str] = None
+    topic_name: Optional[str] = None
+
+    def __post_init__(self):
+        self.bucket_arn = f'arn:aws:s3:::{self.bucket_name}'
+
+    def serializable(self):
+        serialize_keys = [
+            "bucket_name",
+            "region",
+            "account_id",
+            "prefix",
+            "suffix" ,
+            "topic_arn",
+            "topic_name",
+        ]
+        return {
+            key: getattr(self, key) for key in serialize_keys
+        }
+
+@dataclass
+class EventProperties:
+    event_type: str
+
     event_queue_arn: str
     event_queue_name: str = field(init=False)
 
     collection_region: str
-    cust_resources_region: str
-
     collection_account_id: str
-    cust_account_id: str
-
     collection_client: Any
-    cust_resources_client: Any
 
-    topic_arn: Optional[str] = None
-    topic_name: Optional[str] = None
-
-    prefix: Optional[str] = None
-    suffix: Optional[str] = None
+    resource_properties: List[ResourceProperties]
 
     def __post_init__(self):
-        self.bucket_arn = f'arn:aws:s3:::{self.bucket_name}'
-        self.event_queue_name = AWSArn(self.event_queue_arn).resource
+        self.event_queue_name = AWSArn(self.event_queue_arn).resource if self.event_queue_arn else None
+
+    def serializable(self):
+        serialize_keys = [
+            "event_type",
+            "event_queue_arn",
+            "collection_region",
+            "collection_account_id",
+        ]
+        serializable_dict = {
+            key: getattr(self, key) for key in serialize_keys
+        }
+
+        serializable_dict['resource_properties'] = [resource.serializable() for resource in self.resource_properties]
+
+        return serializable_dict
 
 
 @dataclass
