@@ -129,6 +129,39 @@ DATABRICKS_DATA_COLLECTOR_OPTIONS = [
                  required_with_options=['skip_notebook_creation']),
 ]
 
+S3_BUCKET_OPTIONS = [
+    click.option('--bucket', 'bucket_name', required=False, help='Name of bucket to enable events for.'),
+    click.option('--prefix', default=None, callback=convert_empty_str_callback, required=False,
+                  help='Limit the notifications to objects starting with a prefix (e.g. \'data/\').'),
+    click.option('--suffix', default=None, callback=convert_empty_str_callback, required=False,
+                  help='Limit notifications to objects ending with a suffix (e.g. \'.csv\').'),
+    click.option('--topic-arn', default=None, callback=convert_empty_str_callback, required=False,
+                  help='Use an existing SNS topic (same region as the bucket). Creates a topic if one is not specified or '
+                       'if an MCD topic does not already exist in the region.'),
+    click.option('--buckets-filename', required=False, help='Filename that contains bucket config to enable events for',
+                 cls=AdvancedOptions, mutually_exclusive_options=['bucket_name'])
+]
+
+EVENT_TYPE_OPTIONS = [
+    click.option('--event-type', required=True, default=CloudResourceService.MCD_EVENT_TYPE_MD, show_default=True,
+                  help='Type of event to setup.',
+                  type=click.Choice(CloudResourceService.MCD_EVENT_TYPE_FRIENDLY_TO_COLLECTOR_OUTPUT_MAP.keys(), case_sensitive=True)),
+]
+
+RESOURCE_PROFILE_OPTIONS = [
+    click.option('--resource-aws-profile', 'bucket_aws_profile', required=False,
+                  help=f'Override the AWS profile use by the CLI for operations on S3/SNS. {RESOURCE_VERBIAGE}.')
+]
+
+COLLECTOR_PROFILE_OPTIONS = [
+    click.option('--collector-aws-profile', required=False,
+                  help=f'Override the AWS profile use by the CLI for operations on SQS/Collector. {RESOURCE_VERBIAGE}.')
+]
+
+AUTO_YES_OPTIONS = [
+    click.option('--auto-yes', is_flag=True, help='Skip any interactive approval.', default=False, show_default=True)
+]
+
 
 @click.group(help='Manage or integrate an asset with Monte Carlo.')
 def integrations():
@@ -615,30 +648,41 @@ def echo_test_existing(ctx, **kwargs):
     ConnectionOperationsService(config=ctx['config']).echo_test_existing(**kwargs)
 
 
-@integrations.command(help='Setup S3 event notifications for a lake.')
+@integrations.command(help='Setup complete S3 event notifications for a lake.')
 @click.pass_obj
-@click.option('--bucket', 'bucket_name', required=True, help='Name of bucket to enable events for.')
-@click.option('--prefix', default=None, callback=convert_empty_str_callback, required=False,
-              help='Limit the notifications to objects starting with a prefix (e.g. \'data/\').')
-@click.option('--suffix', default=None, callback=convert_empty_str_callback, required=False,
-              help='Limit notifications to objects ending with a suffix (e.g. \'.csv\').')
-@click.option('--topic-arn', default=None, callback=convert_empty_str_callback, required=False,
-              help='Use an existing SNS topic (same region as the bucket). Creates a topic if one is not specified or '
-                   'if an MCD topic does not already exist in the region.')
-@click.option('--collector-aws-profile', required=False,
-              help=f'Override the AWS profile use by the CLI for operations on SQS/Collector. {RESOURCE_VERBIAGE}.')
-@click.option('--resource-aws-profile', 'bucket_aws_profile', required=False,
-              help=f'Override the AWS profile use by the CLI for operations on S3/SNS. {RESOURCE_VERBIAGE}.')
-@click.option('--event-type', required=True, default=CloudResourceService.MCD_EVENT_TYPE_MD, show_default=True,
-              help='Type of event to setup.',
-              type=click.Choice(CloudResourceService.MCD_EVENT_TYPE_FRIENDLY_TO_COLLECTOR_OUTPUT_MAP.keys(), case_sensitive=True))
-@click.option('--auto-yes', is_flag=True, help='Skip any interactive approval.', default=False, show_default=True)
+@add_common_options(S3_BUCKET_OPTIONS)
+@add_common_options(EVENT_TYPE_OPTIONS)
+@add_common_options(COLLECTOR_PROFILE_OPTIONS)
+@add_common_options(RESOURCE_PROFILE_OPTIONS)
+@add_common_options(AUTO_YES_OPTIONS)
 @add_common_options(DISAMBIGUATE_DC_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_events(ctx, **kwargs):
     CloudResourceService(config=ctx['config'], aws_wrapper=None).add_events(**kwargs)
 
 
+@click.pass_obj
+@add_common_options(S3_BUCKET_OPTIONS)
+@add_common_options(EVENT_TYPE_OPTIONS)
+@add_common_options(RESOURCE_PROFILE_OPTIONS)
+@add_common_options(AUTO_YES_OPTIONS)
+@add_common_options(DISAMBIGUATE_DC_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def create_event_topic(ctx, **kwargs):
+    CloudResourceService(config=ctx['config'], aws_wrapper=None).create_event_topic(**kwargs)
+
+@integrations.command(help='Setup Bucket Side S3 event infrastructure for a lake.')
+@click.pass_obj
+@add_common_options(S3_BUCKET_OPTIONS)
+@add_common_options(EVENT_TYPE_OPTIONS)
+@add_common_options(RESOURCE_PROFILE_OPTIONS)
+@add_common_options(AUTO_YES_OPTIONS)
+@add_common_options(DISAMBIGUATE_DC_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def create_bucket_side_event_infrastructure(ctx, **kwargs):
+    CloudResourceService(config=ctx['config'], aws_wrapper=None).create_bucket_side_event_infrastructure(**kwargs)
+
+
 @integrations.command(help='Create an integration key. The resulting key id and secret will be printed to the console.')
 @click.pass_obj
 @click.option('--description',
