@@ -8,6 +8,7 @@ EXPECTED_PRESTO_S3_GQL_RESPONSE_FIELD = 'testS3Credentials'
 EXPECTED_GLUE_GQL_RESPONSE_FIELD = 'testGlueCredentials'
 EXPECTED_ATHENA_GQL_RESPONSE_FIELD = 'testAthenaCredentials'
 EXPECTED_SPARK_GQL_RESPONSE_FIELD = 'testSparkCredentials'
+EXPECTED_DATABRICKS_GQL_RESPONSE_FIELD = 'testDatabricksCredentials'
 EXPECTED_SNOWFLAKE_GQL_RESPONSE_FIELD = 'testSnowflakeCredentials'
 EXPECTED_BQ_GQL_RESPONSE_FIELD = 'testBqCredentials'
 EXPECTED_SELF_HOSTED_GQL_RESPONSE_FIELD = 'testSelfHostedCredentials'
@@ -16,7 +17,6 @@ EXPECTED_UPDATE_CREDENTIALS_RESPONSE_FIELD = 'updateCredentials'
 EXPECTED_REMOVE_CONNECTION_RESPONSE_FIELD = 'removeConnection'
 EXPECTED_TEST_EXISTING_RESPONSE_FIELD = 'testExistingConnection'
 EXPECTED_TEST_TABLEAU_RESPONSE_FIELD = 'testTableauCredentials'
-EXPECTED_ADD_TABLEAU_RESPONSE_FIELD = 'addTableauAccount'
 EXPECTED_LOOKER_METADATA_RESPONSE_FIELD = 'testLookerCredentials'
 EXPECTED_LOOKER_GIT_SSH_RESPONSE_FILED = 'testLookerGitSshCredentials'
 EXPECTED_LOOKER_GIT_CLONE_RESPONSE_FIELD = 'testLookerGitCloneCredentials'
@@ -37,10 +37,12 @@ REDSHIFT_CONNECTION_TYPE = 'redshift'
 SNOWFLAKE_CONNECTION_TYPE = 'snowflake'
 BQ_CONNECTION_TYPE = 'bigquery'
 LOOKER_MD_CONNECTION_TYPE = 'looker'
+TABLEAU_CONNECTION_TYPE = 'tableau'
 LOOKER_GIT_SSH_CONNECTION_TYPE = 'looker-git-ssh'
 LOOKER_GIT_CLONE_CONNECTION_TYPE = 'looker-git-clone'
 DBT_CLOUD_CONNECTION_TYPE = 'dbt-cloud'
 DATABRICKS_METASTORE_CONNECTION_TYPE = 'databricks-metastore'
+DATABRICKS_DELTA_CONNECTION_TYPE = 'databricks-delta'
 
 # Available warehouse types
 DATA_LAKE_WAREHOUSE_TYPE = 'data-lake'
@@ -95,6 +97,7 @@ GQL_TO_FRIENDLY_CONNECTION_MAP = {
     LOOKER_GIT_SSH_CONNECTION_TYPE: 'Looker ML (git)',
     LOOKER_GIT_CLONE_CONNECTION_TYPE: 'Looker ML (git)',
     DBT_CLOUD_CONNECTION_TYPE: 'dbt Cloud',
+    TABLEAU_CONNECTION_TYPE: 'Tableau',
 }
 
 # Verbiage
