@@ -1,3 +1,5 @@
+from montecarlodata.queries.common import GQL
+
 # Queries related to onboarding
 
 TEST_PRESTO_CRED_MUTATION = """
@@ -255,4 +257,39 @@ mutation testDbtCloudCredentials(
     success
   }
 }
-"""
\ No newline at end of file
+"""
+
+class EventOnboardingDataQueries:
+    save = GQL(
+        query="""
+            mutation saveEventOnboardingData($config:JSONString!) {
+              saveEventOnboardingData(config:$config) {
+                success
+              }
+            }
+        """,
+        operation='saveEventOnboardingData'
+    )
+
+    get = GQL(
+        query="""
+            query getEventOnboardingData {
+              getEventOnboardingData {
+                accountUuid
+                config
+              }
+            }        
+            """,
+        operation='getEventOnboardingData'
+    )
+
+    delete = GQL(
+        query="""
+            mutation deleteEventOnboardingData {
+              deleteEventOnboardingData {
+                success
+              }
+            }
+        """,
+        operation='deleteEventOnboardingData'
+    )
